@@ -9,7 +9,7 @@ package Lemonldap::NG::Manager::_i18n;
 
 use strict;
 use AutoLoader qw(AUTOLOAD);
-our $VERSION = '1.4.0';
+our $VERSION = '1.4.11';
 
 ## @method string translate(string text,string lang)
 # Returns $text translated in $lang.
@@ -50,7 +50,9 @@ sub en {
     return {
         _auth                    => 'Authentication',
         _authChoice              => 'Authentication choice',
+        _authMulti               => 'Authentication (multi)',
         _userDB                  => 'User',
+        _userDBMulti             => 'User (multi)',
         _passwordDB              => 'Password',
         _issuerDB                => 'Issuer',
         _timezone                => 'Time zone',
@@ -65,6 +67,9 @@ sub en {
         _samlToken               => 'SAML token',
         _lassoSessionDump        => 'Lasso session dump',
         _lassoIdentityDump       => 'Lasso identity dump',
+        adParams                 => 'Active Directory parameters',
+        ADPwdExpireWarning       => 'Password expire warning',
+        ADPwdMaxAge              => 'Password max age',
         advancedParams           => 'Advanced parameters',
         apacheParams             => 'Apache parameters',
         apacheAuthnLevel         => 'Authentication level',
@@ -163,6 +168,7 @@ sub en {
         grantSessionRules               => 'Opening conditions',
         groups                          => 'Groups',
         headers                         => 'HTTP Headers',
+        hGroups                         => 'Groups (HashRef)',
         hideOldPassword                 => 'Hide old password',
         httpOnly                        => 'Javascript protection',
         https                           => 'HTTPS',
@@ -378,6 +384,7 @@ sub en {
         syslog                      => 'Syslog facility',
         timeout                     => 'Sessions timeout',
         timeoutActivity             => 'Sessions activity timeout',
+        timeoutActivityInterval     => 'Sessions update interval',
         trustedDomains              => 'Trusted domains',
         trustedProxies              => 'Trusted proxies IP',
         twitterAppName              => 'Application name',
@@ -457,6 +464,7 @@ sub en {
         samlIDPMetaDataOptionsSignature       => 'Signature',
         samlIDPMetaDataOptionsBinding         => 'Binding',
         samlIDPMetaDataOptionsSecurity        => 'Security',
+        samlIDPMetaDataOptionsStoreSAMLToken  => 'Store SAML Token',
         samlSPMetaDataNode                    => 'SAML service providers',
         samlSPMetaDataXML                     => 'Metadata',
         samlSPMetaDataExportedAttributes      => 'Exported attributes',
@@ -551,37 +559,42 @@ sub en {
 sub fr {
     use utf8;
     return {
-        _auth                    => 'Authentification',
-        _authChoice              => 'Choix d\'authentification',
-        _userDB                  => 'Utilisateur',
-        _passwordDB              => 'Mot de passe',
-        _issuerDB                => 'Fournisseur',
-        _timezone                => 'Zone horaire',
-        _session_id              => 'Identifiant de session',
-        _url                     => "URL d'origine",
-        _user                    => 'Identifiant',
-        _password                => 'Mot de passe',
-        _utime                   => 'Tampon de la session',
-        _lastAuthnUTime          => 'Tampon d\'authentification ',
-        _idp                     => 'Identifiant d\'entité de l\'IDP',
-        _idpConfKey              => 'Clé de configuration de l\'IDP',
-        _samlToken               => ' Jeton SAML ',
-        _lassoSessionDump        => ' Dump session Lasso ',
-        _lassoIdentityDump       => 'Dump identité Lasso',
-        advancedParams           => 'Paramètres avancés',
-        apacheParams             => 'Paramètres Apache',
-        apacheAuthnLevel         => 'Niveau d\'authentification',
-        applicationList          => 'Catégories et applications',
-        attributesAndMacros      => 'Attributs et macros',
-        authChoiceModules        => 'Modules autorisés',
-        authChoiceParam          => 'Parmètre de l\'URL',
-        authentication           => "Module d'authentification",
-        authenticationLevel      => 'Niveau d\'authentification',
-        authenticationTitle      => 'Authentification',
-        AuthLDAPFilter           => 'Filtre d\'authentification',
-        authParams               => "Modules d'authentification",
-        browserIdAuthnLevel      => "Niveau d'authentification",
-        browserIdAutoLogin       => "Authentification automatique",
+        _auth               => 'Authentification',
+        _authChoice         => 'Choix d\'authentification',
+        _authMulti          => 'Authentification (multi)',
+        _userDB             => 'Utilisateur',
+        _userDBMulti        => 'Utilisateur (multi)',
+        _passwordDB         => 'Mot de passe',
+        _issuerDB           => 'Fournisseur',
+        _timezone           => 'Zone horaire',
+        _session_id         => 'Identifiant de session',
+        _url                => "URL d'origine",
+        _user               => 'Identifiant',
+        _password           => 'Mot de passe',
+        _utime              => 'Tampon de la session',
+        _lastAuthnUTime     => 'Tampon d\'authentification ',
+        _idp                => 'Identifiant d\'entité de l\'IDP',
+        _idpConfKey         => 'Clé de configuration de l\'IDP',
+        _samlToken          => ' Jeton SAML ',
+        _lassoSessionDump   => ' Dump session Lasso ',
+        _lassoIdentityDump  => 'Dump identité Lasso',
+        adParams            => 'Paramètres Active Directory',
+        ADPwdExpireWarning  => 'Avertissement avant expiration du mot de passe',
+        ADPwdMaxAge         => 'Âge maximal du mot de passe',
+        advancedParams      => 'Paramètres avancés',
+        apacheParams        => 'Paramètres Apache',
+        apacheAuthnLevel    => 'Niveau d\'authentification',
+        applicationList     => 'Catégories et applications',
+        attributesAndMacros => 'Attributs et macros',
+        authChoiceModules   => 'Modules autorisés',
+        authChoiceParam     => 'Parmètre de l\'URL',
+        authentication      => "Module d'authentification",
+        authenticationLevel => 'Niveau d\'authentification',
+        authenticationTitle => 'Authentification',
+        AuthLDAPFilter      => 'Filtre d\'authentification',
+        authParams          => "Modules d'authentification",
+        browserIdAuthnLevel => "Niveau d'authentification",
+        browserIdAutoLogin  => "Authentification automatique",
         browserIdBackgroundColor => "Couleur d'arrière plan",
         browserIdParams          => "Paramètres BrowserID",
         browserIdSiteLogo        => "Logo du site",
@@ -669,6 +682,7 @@ sub fr {
         grantSessionRules      => "Conditions d'ouverture",
         groups                 => 'Groupes',
         headers                => 'En-têtes HTTP',
+        hGroups                => 'Groupes (HashRef)',
         hideOldPassword        => "Masquer l'ancien mot de passe",
         httpOnly               => 'Protection contre javascript',
         https                  => 'HTTPS',
@@ -882,28 +896,29 @@ sub fr {
         SSLVar             => 'Champ extrait du certificat',
         startTime          => 'Date de création',
         storePassword => "Stocke le mot de passe de l'utilisateur en session",
-        successLoginNumber => 'Nombre de connexions mémorisées',
-        sympaHandler       => 'Sympa',
-        sympaMailKey       => 'Clé de session pour le mail',
-        sympaSecret        => 'Secret partagé',
-        syntaxError        => 'Erreur de syntaxe',
-        syslog             => 'Facilité syslog',
-        timeout            => 'Durée de vie maximale des sessions',
-        timeoutActivity    => 'Délai d\'expiration des sessions',
-        trustedDomains     => 'Domaines approuvés',
-        trustedProxies     => 'IP des proxys de confiance',
-        twitterAppName     => 'Nom de l\'application',
-        twitterAuthnLevel  => 'Niveau d\'authentification',
-        twitterKey         => 'Clé de l\'API',
-        twitterParams      => 'Paramètres Twitter',
-        twitterSecret      => 'Secret de l\'API',
-        unknownError       => 'Erreur inconnue',
-        updateTime         => 'Date de mise à jour',
-        uploadDenied       => 'Téléchargement refusé',
-        user               => 'utilisateur',
-        users              => 'utilisateurs',
-        userDB             => "Module d'utilisateurs",
-        userControl        => "Contrôle du nom d'utilisateur",
+        successLoginNumber      => 'Nombre de connexions mémorisées',
+        sympaHandler            => 'Sympa',
+        sympaMailKey            => 'Clé de session pour le mail',
+        sympaSecret             => 'Secret partagé',
+        syntaxError             => 'Erreur de syntaxe',
+        syslog                  => 'Facilité syslog',
+        timeout                 => 'Durée de vie maximale des sessions',
+        timeoutActivity         => 'Délai d\'expiration des sessions',
+        timeoutActivityInterval => 'Intervalle de mise à jour des sessions',
+        trustedDomains          => 'Domaines approuvés',
+        trustedProxies          => 'IP des proxys de confiance',
+        twitterAppName          => 'Nom de l\'application',
+        twitterAuthnLevel       => 'Niveau d\'authentification',
+        twitterKey              => 'Clé de l\'API',
+        twitterParams           => 'Paramètres Twitter',
+        twitterSecret           => 'Secret de l\'API',
+        unknownError            => 'Erreur inconnue',
+        updateTime              => 'Date de mise à jour',
+        uploadDenied            => 'Téléchargement refusé',
+        user                    => 'utilisateur',
+        users                   => 'utilisateurs',
+        userDB                  => "Module d'utilisateurs",
+        userControl             => "Contrôle du nom d'utilisateur",
         userPivot => 'Champ identifiant dans la table des utilisateurs',
         useRedirectOnError     => 'Redirection pour les erreurs',
         useRedirectOnForbidden => 'Redirection pour les accès interdits',
@@ -971,6 +986,7 @@ sub fr {
         samlIDPMetaDataOptionsSignature       => 'Signature',
         samlIDPMetaDataOptionsBinding         => 'Méthode',
         samlIDPMetaDataOptionsSecurity        => 'Sécurité',
+        samlIDPMetaDataOptionsStoreSAMLToken  => 'Conserver le jeton SAML',
         samlSPMetaDataNode                    => 'Fournisseurs de service SAML',
         samlSPMetaDataXML                     => 'Metadonnées',
         samlSPMetaDataExportedAttributes      => 'Attributs exportés',
